@@ -26,7 +26,7 @@ public:
     /**
      * Constructor.
      */
-    CPPSourceCodeOperation(CPPSourceCodeDocument * doc, UMLOperation * op, const QString & body = "", const QString & comment = "");
+    CPPSourceCodeOperation(CPPSourceCodeDocument * doc, UMLOperation * op, const QString & body = QString(), const QString & comment = QString());
 
     /**
      * Empty Destructor
